#!/bin/bash
#

# build_caencomm.sh <product_dir> [tar]

# if this build script complains that it cannot find bzlib.h, 
# you need to install bzip2-devel on Scientific Linux

usage()
{
   echo "USAGE: `basename ${0}` <product_dir> [tar]"
}

# -------------------------------------------------------------------
# shared boilerplate
# -------------------------------------------------------------------

get_this_dir() 
{
    ( cd / ; /bin/pwd -P ) >/dev/null 2>&1
    if (( $? == 0 )); then
      pwd_P_arg="-P"
    fi
    reldir=`dirname ${0}`
    thisdir=`cd ${reldir} && /bin/pwd ${pwd_P_arg}`
}

get_ssibuildshims()
{
    # make sure we can use the setup alias
    if [ -z ${UPS_DIR} ]
    then
       echo "ERROR: please setup ups"
       exit 1
    fi
    source `${UPS_DIR}/bin/ups setup ${SETUP_UPS}`
    
    setup ssibuildshims ${ssibuildshims_version} -z ${product_dir}
}

get_platform_name()
{
    OS1=`uname`
    flvr=`ups flavor`
    if [ ${OS1} = "Darwin" ]
    then
        echo "ERROR: this package is not available for OSX"
        exit 1
    fi
    OS=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform`
    plat=`${SSIBUILDSHIMS_DIR}/bin/get_os_platform osplat`

    if [ -z ${flvr} ]
    then
       echo "ERROR: could not determine flavor for this platform"
       echo "       something is very wrong"
       exit 1
    fi

    pkgdir=${product_dir}/${package}/${pkgver}/${flvr}
    blddir=${product_dir}/${package}/${pkgver}/build/${flvr}
    tardir=${product_dir}/${package}/${pkgver}/tar
    patchdir=${product_dir}/${package}/${pkgver}/patch
}

die()
{
  echo "$1"; exit 2
}

# -------------------------------------------------------------------
# start processing
# -------------------------------------------------------------------

product_dir=${1}
maketar=${2}

if [ -z ${product_dir} ]
then
   echo "ERROR: please specify the local product directory"
   usage
   exit 1
fi

# -------------------------------------------------------------------
# package name and version
# -------------------------------------------------------------------

package=caencomm
origpkgver=v1_2
pkgver=${origpkgver}a
ssibuildshims_version=v0_09_02
pkgdotver=`echo ${origpkgver} | sed -e 's/_/./g' | sed -e 's/^v//'`
pkgtarfile=CAENComm-${pkgdotver}-build20140211.tgz

get_this_dir

get_ssibuildshims
 
get_platform_name

if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
   exit 0
fi

echo "building ${package} for ${OS}-${plat} (flavor ${flvr})"

# -------------------------------------------------------------------
# package dependent stuff goes here
# -------------------------------------------------------------------

mkdir -p ${blddir}
if [ ! -d ${blddir} ]
then
   echo "ERROR: failed to create ${blddir}"
   exit 1
fi

incdir=${product_dir}/${package}/${pkgver}/include
docdir=${product_dir}/${package}/${pkgver}/doc
libdir=${pkgdir}/lib

set -x

cd ${pkgdir}
mkdir  -p ${incdir} ${docdir} ${libdir}  || die "could not create subdirectories"

cd ${blddir}
tar xf ${tardir}/${pkgtarfile} || die "unable to unwind ${pkgtarfile}"

cp -p ${blddir}/CAENComm-${pkgdotver}/lib/x64/libCAENComm.so.${pkgdotver}.0 ${libdir} || die "unable to copy libCAENComm.so.${pkgdotver}.0"
cd ${libdir}
ln -sf libCAENComm.so.${pkgdotver}.0 libCAENComm.so || die "unable to create symbolic link"
cd ${pkgdir}
cp -p ${blddir}/CAENComm-${pkgdotver}/include/* ${incdir}/ || die "unable to copy headers"
cp -p ${blddir}/CAENComm-${pkgdotver}/*.txt ${docdir}/  || die "unable to copy txt files"
cp -p ${blddir}/CAENComm-${pkgdotver}/lib/install* ${docdir}/ || die "unable to copy install scripts"

set +x

${SSIBUILDSHIMS_DIR}/bin/declare_product ${product_dir} ${package} ${pkgver} NO_QUAL || die "declare_product failed"

#-------------------------------------------------------------------
# common bottom stuff
# -------------------------------------------------------------------

# this should not complain
echo "Finished building ${package} ${pkgver}"
setup ${package} ${pkgver} -z ${product_dir}:${PRODUCTS} || die "setup failed"
echo "${package} is installed at ${CAENCOMM_DIR}"

# this must be last 
if [ "${maketar}" = "tar" ] && [ -d ${pkgdir}/lib ]
then
   ${SSIBUILDSHIMS_DIR}/bin/make_distribution_tarball ${product_dir} ${package} ${pkgver} NO_QUAL
fi

exit 0
